<template>
    <div class="patrol-work-order">
        <div class="inner-form">
            <el-form
                v-form
                data-vv-scope="taskManageForm"
                :model="form"
                :rules="rules"
                ref="taskManageForm"
                label-width="80px"
            >
                <el-row>
                    <el-col :span="12">
                        <el-form-item label="所在路段" prop="form.roadSegmentId">
                            <el-select
                                v-model="form.roadSegmentId"
                                placeholder="请选择路段名称"
                                style="width: 100%"
                                @change="handleRoadSegmentChanged"
                                clearable
                            >
                                <el-option
                                    v-for="item in roadSegmentOptions"
                                    :key="item.id"
                                    :label="item.name"
                                    :value="item.id"
                                ></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12">
                        <el-form-item label="项目名称" prop="projectName">
                            <div @click="openProjectName(form)" style="cursor: pointer">
                                <el-input
                                    suffix-icon="el-icon-search"
                                    v-model="form.projectName"
                                    placeholder="请选择项目名称"
                                ></el-input>
                            </div>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12">
                        <el-form-item label="质检时间" prop="testTime">
                            <el-date-picker
                                v-model="form.testTime"
                                type="date"
                                placeholder="选择日期"
                                format="yyyy-MM-dd"
                                value-format="yyyy-MM-dd"
                                style="width: 100%"
                            >
                            </el-date-picker>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12">
                        <el-form-item label="质检地点" prop="testLocation">
                            <el-input
                                v-model="form.testLocation"
                                placeholder="质检地点"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12">
                        <el-form-item label="有无质检问题" prop="testResult">
                            <dict-select
                                dictCode="gczlgl-ywzlwt"
                                :hasDefaultOption="true"
                                clearable
                                v-model="form.testResult"
                                style="width: 100%"
                            />
                        </el-form-item>
                    </el-col>
                    <el-col :span="12">
                        <el-form-item label="质检员" prop="testUserName">
                            <el-input
                                v-model="form.testUserName"
                                placeholder="请输入质检员"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="24">
                        <el-form-item label="附件管理" prop="accessories">
                            <file-upload
                                :dadToSon="dadToSon"
                                @sonToDad="sonToDad"
                            ></file-upload>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <projectDialog ref="reference" @common="backData"></projectDialog>
        </div>
    </div>
</template>

<script>
import {helper} from '../../../public/hotent.helper.js'
import req from '@/request.js'
import utils from '@/utils'
import basicData from '@/api/basicData.js'
import projectDialog from '@/components/dialog/projectDialog.vue'
import companyInfoSelector from '@/components/selector/companyInfoSelector.vue'
import EipUserSelector from '@/components/eipControl/selector/EipUserSelector.vue'
import DictSelect from '@/components/dict/DictSelect.vue'
import fileUpload from '@/components/upload/fileUploadProject.vue'

export default {
    name: 'PatrolWorkOrder', // 巡检工单
    components: {
        projectDialog,
        EipUserSelector,
        DictSelect,
        companyInfoSelector,
        fileUpload,
    },
    data() {
        return {
            currentNode: 1,
            form: {
                roadSegmentId: '',
            },
            rules: {
                roadSegmentId: {
                    required: true,
                    message: '请选择路段',
                    trigger: 'change',
                },
                projectName: {
                    required: true,
                    message: '请输入项目名称',
                    trigger: 'change',
                },
                testTime: {
                    required: true,
                    message: '请输入质检时间',
                    trigger: 'blur',
                },
                testLocation: {
                    required: true,
                    message: '请输入质检地点',
                    trigger: 'blur',
                },
                testResult: {
                    required: true,
                    message: '请选择有无质检问题',
                    trigger: 'blur',
                },
                testUserName: {
                    required: true,
                    message: '请选择质检员',
                    trigger: 'blur',
                },
            },
            roadSegmentOptions: [], // 路段数据
            dadToSon: {
                bizPath: 'specialproject', //附件
                fileList: [],
            },
        }
    },
    created() {
        this.getRoadSegmentData() //获取路段数据
    },
    mounted() {
        this.currentNode = this.$route.query.node
        const _this = this
        window.saveData = this.saveData
        this.id = utils.getUrlKey('id')
        let isEdit = utils.getUrlKey('isEdit')
        this.disabled = isEdit == 'r' ? true : false
        if (this.id) {
            req.get(window.context.yhxt + '/siteInspection/v1/get/' + this.id).then(
                (res) => {
                    if (res.data) {
                        res.data.type ? (res.data.type = res.data.type + '') : null
                        _this.form = res.data
                    }
                }
            )
        }
    },
    methods: {
        //获取路段下拉信息
        getDataInfo() {
            // 获取路段信息
            basicData.getRoadManagement().then((res) => {
                this.roadData = res.rows
            })
            // 获取病害类别
            if (this.options.length == 0) {
                let data = 'CBKM'
                basicData.getCostAccountManagement(data).then((res) => {
                    res.data.forEach((item) => {
                        this.options.push({
                            label: item.subjectName,
                            value: item.subjectCode,
                        })
                    })
                })
            }
            //获取公司信息
            this.$http.post('${yhxt}/Company/v1/getCompany').then((res) => {
                res.data.forEach((item) => {
                    this.companyOptions.push({
                        id: item.id,
                        name: item.name,
                    })
                })
            })
        },
        sonToDad(data) {
            console.log(data)
            let arr = []
            data.forEach((item) => {
                arr.push({
                    isDele: item.isDele,
                    attachmentName: item.name,
                    attachmentPath: item.url,
                    attachmentSuffix: item.suffix,
                    attachmentType: item.type,
                    type: 0,
                })
            })
            this.accessories = arr
            this.form.accessories = arr
            // 防止用户打开了文件选择框之后不选择文件而出现效验失败
            if (this.form.accessories) {
                this.$refs.form.clearValidate('accessories')
            }
        },
        backData(data) {
            console.log(data, 'data')
            this.form.projectId = data[0].id
            this.form.projectName = data[0].projectName
            this.$forceUpdate()
            const field = 'projectName' // 替换为要清除校验的字段名
            const rules = this.$refs.form.rules
            if (rules && rules[field]) {
                this.$refs.form.clearValidate(field)
            }
        },
        openProjectName(val) {
            this.$nextTick(() => {
                this.$refs.reference.open(val)
            })
        },
        // 获取路段数据
        getRoadSegmentData() {
            basicData.getRoadManagement().then((res) => {
                if (res.rows.length !== 0) {
                    this.roadSegmentOptions = res.rows
                }
            })
        },
        handleRoadSegmentChanged(id) {
            this.roadSegmentOptions.forEach((item) => {
                if (item.id == id) {
                    this.form = {
                        companyName: item.companyName,
                        companyId: item.companyId,
                        roadSegmentName: item.name,
                        roadSegmentId: id,
                        projectId: '',
                        projectName: '',
                        ...this.form,
                    }
                    this.projectOptions = []
                    this.getProjectInfo(id)
                }
            })
        },
        //深层拷贝回去公司名称
        deepClone(obj) {
            let objClone = Array.isArray(obj) ? [] : {}
            if (obj && typeof obj === 'object') {
                for (let key in obj) {
                    if (obj.hasOwnProperty(key)) {
                        //判断ojb子元素是否为对象，如果是，递归复制
                        if (obj[key] && typeof obj[key] === 'object') {
                            objClone[key] = this.deepClone(obj[key])
                        } else {
                            if (obj[key] == obj.name) {
                                this.companyOptions.push({
                                    id: obj.id,
                                    name: obj.name,
                                })
                            }
                            //如果不是，简单复制
                            objClone[key] = obj[key]
                        }
                    }
                }
            }
        },
        //字典回调,赋值
        handleSelectValue(val, obj, str) {
            if (str == 'xjlb') {
                this.tableData.forEach((item) => {
                    if (item.key == obj.key) {
                        item.typeName = obj.name
                    }
                })
            } else if (str == 'fx') {
                this.tableData.forEach((item) => {
                    if (item.key == obj.key) {
                        item.directionName = obj.name
                    }
                })
            } else if (str == 'bhbw') {
                this.tableData.forEach((item) => {
                    if (item.key == obj.key) {
                        item.positionName = obj.name
                    }
                })
            }
        },
        /* 添加病害结束 */
        saveData() {
            const _this = this
            //验证表单是否填写完
            this.$refs.taskManageForm.validate((pass) => {
                if (pass) {
                    //请求保存提交
                    console.log(this.form, 'this.form')
                    this.$http
                        .post(
                            '${yhxt}/siteInspection/v1/saveSiteInspectionSpecial',
                            this.form
                        )
                        .then((res) => {
                            if (res.data.state) {
                                let params = {
                                    type: 'saveData',
                                    state: true,
                                    businessKey: res.data.value.id,
                                    sysCode: '',
                                }
                                // params.vars = {
                                //     props1: this.forms.props1,
                                // }
                                hotent.sendMessage(params)
                            }
                        })
                }
            })
        },
    },
}
</script>

<style lang='scss' scoped>
.index-inner {
    display: flex;
    justify-content: center;
    height: 100%;
    background-color: #fff;
}
.patrol-work-order {
    width: 100%;
    height: 100%;
    margin: 0 auto;
    background: #fff;
    .inner-form {
        width: 600px;
        margin: 0 auto;
        .card-box {
        max-width: 100%;
        min-width: 1200px;
        box-sizing: border-box;
        position: absolute;
        top: 280px;
        left: 50%;
        transform: translateX(-50%);
        }
    }
}
// /deep/ .el-select-dropdown__item.hover,
// .el-select-dropdown__item:hover {
//   background-color: #409eff !important;
//   color: #fff !important;
// }
</style>